@@ -557,6 +557,10 @@ class WorkflowQuery:
         self.sbx_workflow = sbx_workflow
         self.url = self.sbx_workflow.urls['api'] + self.sbx_workflow.environment['domain'] + self.sbx_workflow.urls['list_process_execution']
 
+    def setUrl(self, url):
+        self.url = self.sbx_workflow.urls['api'] + self.sbx_workflow.environment['domain'] + url
+        return self
+
     def __chunk_it(self, seq, num):
         avg = len(seq) / float(num)
         out = []
@@ -648,6 +652,9 @@ class SbxWorkflow:
     def with_process_execution(self):
         return WorkflowQuery(self)
 
+    def with_url(self, url):
+        return WorkflowQuery(self).setUrl(url)
+
 class UserQuery:
 
     def __init__(self, crm_user):
@@ -655,6 +662,10 @@ class UserQuery:
         self.url = self.crm_user.urls['api'] + self.crm_user.environment['domain'] + self.crm_user.urls[
             'list_users']
 
+    def setUrl(self, url):
+        self.url = self.crm_user.urls['api'] + self.crm_user.environment['domain'] + url
+        return self
+
     def __chunk_it(self, seq, num):
         avg = len(seq) / float(num)
         out = []
@@ -743,4 +754,7 @@ class SbxCRMUser:
         return self
 
     def with_process_execution(self):
-        return UserQuery(self)
\ No newline at end of file
+        return UserQuery(self)
+
+    def with_url(self, url):
+        return UserQuery(self).setUrl(url)
\ No newline at end of file
